@@ -2,7 +2,7 @@ import bluetooth
 import sys
 from prompt_toolkit.shortcuts import checkboxlist_dialog, yes_no_dialog
 from prompt_toolkit.styles import Style
-from ImuSensor import MODE_WIRELESS, ImuSensor
+from .ImuSensor import MODE_WIRELESS, ImuSensor
 
 prompt_style = Style.from_dict({
     'dialog': '#ffffff bg:',
